/*
 * Copyright 2012 Adaptrex, LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.adaptrex.security.servlet;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authc.UsernamePasswordToken;
import org.apache.shiro.subject.Subject;
import org.apache.shiro.web.util.SavedRequest;
import org.apache.shiro.web.util.WebUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.fasterxml.jackson.databind.ObjectMapper;

@WebServlet(name="Adaptrex Logout", urlPatterns={"/ax-login"}) 
public class LogInServlet extends HttpServlet { 
	private static final long serialVersionUID = 1L;
	
	private static ObjectMapper mapper = new ObjectMapper();
	private static Logger log = LoggerFactory.getLogger(LogInServlet.class);
	
	protected void doPost(HttpServletRequest request, HttpServletResponse response) {
		Map<String,Object> responseMap = new HashMap<String,Object>();
		
		try {
			response.setContentType("application/json");
			Subject subject = SecurityUtils.getSubject();
			
			UsernamePasswordToken token = new UsernamePasswordToken(request.getParameter("username"), request.getParameter("password"));
		    token.setRememberMe(request.getParameter("rememberMe") != null && request.getParameter("rememberMe").equals("on"));

		    try {
		    	subject.login(token);
		    	
				String redirect = request.getContextPath();
				SavedRequest oldRequest = WebUtils.getSavedRequest(request);
				if (oldRequest != null && oldRequest.getRequestURI() != null) {
					redirect = oldRequest.getRequestURI();
				}
				if (redirect.isEmpty()) redirect = "/";
		    	
		    	responseMap.put("success", true);
		    	responseMap.put("redirect", redirect);
			} catch (Exception e) {
				responseMap.put("success", false);
			}
			
		    try {
		    	response.getWriter().print(mapper.writeValueAsString(responseMap));
			} catch (Exception e) {
				response.getWriter().print("");
			}
			
		} catch (Exception e) {
			log.warn("Error", e);
		} 
	}
} 